@@ -29,10 +29,13 @@ test_that("nhd_plus_query fails well", {
   expect_error(
     nhdR::nhd_plus_query(lat = coords$lat,
       lon = coords$lon,
-      dsn = "NHDFlowLine",
-      buffer_dist = 0.1),
+      dsn = "NHDFlowLine"),
     "nhd_plus_query only accepts a single lon-lat pair.")
 
+  expect_error(
+    nhdR::nhd_plus_query(dsn = "NHDWaterbody", wkt_filter = "POINT (-85.411 42.399)"),
+    "Must specify either lon and lat or poly but not both.")
+
 
   # query will produce a zero row sf object when appropriate
   coords <- data.frame(lat = c(42.04133),
@@ -68,4 +71,19 @@ test_that("nhd_query works.", {
   wk <- wikilake::lake_wiki("Worden Pond")
   qry <- nhd_query(wk$Lon, wk$Lat, dsn = c("NHDWaterbody", "NHDFlowline"))
   testthat::expect_s3_class(qry$sp$NHDWaterbody, "data.frame")
+})
+
+test_that("nhd_query works with polygon inputs", {
+  skip_on_cran()
+  skip_on_ci()
+
+  bbox <- sf::st_bbox(
+    c(xmin = 283389.1, ymin = 4589520.3, xmax = 286345.2, ymax = 4591955.5),
+    crs = "+proj=utm +zone=19 +datum=WGS84")
+  qry <- nhd_query(poly = sf::st_as_sfc(bbox), dsn = c("NHDWaterbody", "NHDFlowLine"))
+  # mapview(bbox) + mapview(qry$sp$NHDWaterbody) + mapview(qry$sp$NHDFlowLine)
+
+  testthat::expect_lt(nrow(qry$sp$NHDWaterbody), 20)
+  testthat::expect_s3_class(qry$sp$NHDWaterbody, "data.frame")
+  testthat::expect_lt(nrow(qry$sp$NHDFlowLine), 20)
 })
\ No newline at end of file
